@@ -2,9 +2,9 @@
 /*
  * This file is part of EC-CUBE
  *
- * Copyright(c) 2000-2015 LOCKON CO.,LTD. All Rights Reserved.
+ * Copyright(c) EC-CUBE CO.,LTD. All Rights Reserved.
  *
- * http://www.lockon.co.jp/
+ * http://www.ec-cube.co.jp/
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ use Eccube\Util\EntityUtil;
 /**
  * Member
  */
-class Member extends \Eccube\Entity\AbstractEntity implements UserInterface
+class Member extends \Eccube\Entity\AbstractEntity implements UserInterface, \Serializable
 {
     public static function loadValidatorMetadata(ClassMetadata $metadata)
     {
@@ -454,4 +454,41 @@ class Member extends \Eccube\Entity\AbstractEntity implements UserInterface
     {
         return $this->login_date;
     }
+
+    /**
+     * String representation of object
+     * @link http://php.net/manual/en/serializable.serialize.php
+     * @return string the string representation of the object or null
+     * @since 5.1.0
+     */
+    public function serialize()
+    {
+        // see https://symfony.com/doc/2.7/security/entity_provider.html#create-your-user-entity
+        // MemberRepository::loadUserByUsername() で Work をチェックしているため、ここでは不要
+        return serialize(array(
+            $this->id,
+            $this->login_id,
+            $this->password,
+            $this->salt,
+        ));
+    }
+
+    /**
+     * Constructs the object
+     * @link http://php.net/manual/en/serializable.unserialize.php
+     * @param string $serialized <p>
+     * The string representation of the object.
+     * </p>
+     * @return void
+     * @since 5.1.0
+     */
+    public function unserialize($serialized)
+    {
+        list (
+            $this->id,
+            $this->login_id,
+            $this->password,
+            $this->salt,
+            ) = unserialize($serialized);
+    }
 }
