@@ -2,9 +2,9 @@
 /*
  * This file is part of EC-CUBE
  *
- * Copyright(c) 2000-2015 LOCKON CO.,LTD. All Rights Reserved.
+ * Copyright(c) EC-CUBE CO.,LTD. All Rights Reserved.
  *
- * http://www.lockon.co.jp/
+ * http://www.ec-cube.co.jp/
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 
 namespace Eccube\Form\Type;
 
+use Eccube\Entity\CustomerAddress;
 use Doctrine\ORM\EntityRepository;
 use Symfony\Component\Form\AbstractType;
 use Symfony\Component\Form\FormBuilderInterface;
@@ -86,14 +87,21 @@ class ShippingMultipleItemType extends AbstractType
                     // 非会員の場合、セッションに設定されたCustomerAddressを設定
                     if ($app['session']->has('eccube.front.shopping.nonmember.customeraddress')) {
                         $customerAddresses = $app['session']->get('eccube.front.shopping.nonmember.customeraddress');
-                        $customerAddresses = unserialize($customerAddresses);
+                        $customerAddresses = json_decode($customerAddresses, true);
 
                         $addresses = array();
-                        $i = 0;
-                        /** @var \Eccube\Entity\CustomerAddress $CustomerAddress */
-                        foreach ($customerAddresses as $CustomerAddress) {
-                            $addresses[$i] = $CustomerAddress->getShippingMultipleDefaultName();
-                            $i++;
+                        /** @var \Eccube\Entity\CustomerAddress $value */
+                        foreach ($customerAddresses as $value) {
+
+                            $customerAddressArray = (array) $value;
+                            $customerAddressArray['Pref'] = (array) $customerAddressArray['Pref'];
+
+                            $CustomerAddress = new CustomerAddress();
+                            $CustomerAddress->setPropertiesFromArray($customerAddressArray);
+                            $CustomerAddress->setCustomer($app['eccube.service.shopping']->getNonMember('eccube.front.shopping.nonmember'));
+                            $CustomerAddress->setPref($app['eccube.repository.master.pref']->find($customerAddressArray['Pref']['id']));
+
+                            $addresses[] = $CustomerAddress->getShippingMultipleDefaultName();
                         }
                         $form->add('customer_address', 'choice', array(
                             'choices' => $addresses,
