@@ -9,8 +9,10 @@ use Eccube\Entity\CustomerAddress;
 use Eccube\Entity\Delivery;
 use Eccube\Entity\DeliveryTime;
 use Eccube\Entity\DeliveryFee;
+use Eccube\Entity\Master\DeviceType;
 use Eccube\Entity\Order;
 use Eccube\Entity\OrderDetail;
+use Eccube\Entity\PageLayout;
 use Eccube\Entity\Payment;
 use Eccube\Entity\PaymentOption;
 use Eccube\Entity\Product;
@@ -243,9 +245,12 @@ class Generator {
      *
      * @param string $product_name 商品名. null の場合はランダムな文字列が生成される.
      * @param integer $product_class_num 商品規格の生成数
+     * @param string $image_type 生成する画像タイプ.
+     *        abstract, animals, business, cats, city, food, night, life, fashion, people, nature, sports, technics, transport から選択可能
+     *        null の場合は、画像を生成せずにファイル名のみを設定する.
      * @return \Eccube\Entity\Product
      */
-    public function createProduct($product_name = null, $product_class_num = 3)
+    public function createProduct($product_name = null, $product_class_num = 3, $image_type = null)
     {
         $faker = $this->getFaker();
         $Member = $this->app['eccube.repository.member']->find(2);
@@ -270,9 +275,18 @@ class Generator {
 
         for ($i = 0; $i < 3; $i++) {
             $ProductImage = new ProductImage();
+            if ($image_type) {
+                $image = $faker->image(
+                    __DIR__.'/../../../../html/upload/save_image',
+                    $faker->numberBetween(480, 640),
+                    $faker->numberBetween(480, 640),
+                    $image_type, false);
+            } else {
+                $image = $faker->word.'.jpg';
+            }
             $ProductImage
                 ->setCreator($Member)
-                ->setFileName($faker->word.'.jpg')
+                ->setFileName($image)
                 ->setRank($i)
                 ->setProduct($Product);
             $this->app['orm.em']->persist($ProductImage);
@@ -322,6 +336,10 @@ class Generator {
 
             $this->app['orm.em']->persist($ProductClass);
             $this->app['orm.em']->flush($ProductClass);
+
+            $ProductStock->setProductClass($ProductClass);
+            $ProductStock->setProductClassId($ProductClass->getId());
+            $this->app['orm.em']->flush($ProductStock);
             $Product->addProductClass($ProductClass);
         }
 
@@ -351,6 +369,11 @@ class Generator {
             ->setProduct($Product);
         $this->app['orm.em']->persist($ProductClass);
         $this->app['orm.em']->flush($ProductClass);
+
+        $ProductStock->setProductClass($ProductClass);
+        $ProductStock->setProductClassId($ProductClass->getId());
+        $this->app['orm.em']->flush($ProductStock);
+
         $Product->addProductClass($ProductClass);
 
         $Categories = $this->app['eccube.repository.category']->findAll();
@@ -383,13 +406,17 @@ class Generator {
      * @param integer $add_discount Order に加算される値引き額
      * @return \Eccube\Entity\Order
      */
-    public function createOrder(Customer $Customer, array $ProductClasses = array(), Delivery $Delivery = null, $add_charge = 0, $add_discount = 0)
+    public function createOrder(Customer $Customer, array $ProductClasses = array(), Delivery $Delivery = null, $add_charge = 0, $add_discount = 0, $statusType = null)
     {
         $faker = $this->getFaker();
         $quantity = $faker->randomNumber(2);
         $Pref = $this->app['eccube.repository.master.pref']->find($faker->numberBetween(1, 47));
         $Payments = $this->app['eccube.repository.payment']->findAll();
-        $Order = new Order($this->app['eccube.repository.order_status']->find($this->app['config']['order_processing']));
+        if(!$statusType){
+            $statusType = 'order_processing';
+        }
+        $OrderStatus = $this->app['eccube.repository.order_status']->find($this->app['config'][$statusType]);
+        $Order = new Order($OrderStatus);
         $Order->setCustomer($Customer);
         $Order->copyProperties($Customer);
         $Order
@@ -583,6 +610,32 @@ class Generator {
         return $Delivery;
     }
 
+    /**
+     * ページを生成する
+     *
+     * @return PageLayout
+     */
+    public function createPageLayout()
+    {
+        $faker = $this->getFaker();
+        $DeviceType = $this->app['eccube.repository.master.device_type']->find(DeviceType::DEVICE_TYPE_PC);
+        /** @var PageLayout $PageLayout */
+        $PageLayout = $this->app['eccube.repository.page_layout']->newPageLayout($DeviceType);
+        $PageLayout
+            ->setName($faker->word)
+            ->setUrl($faker->word)
+            ->setFileName($faker->word)
+            ->setAuthor($faker->word)
+            ->setDescription($faker->word)
+            ->setKeyword($faker->word)
+            ->setMetaRobots($faker->word)
+            ->setMetaTags('<meta name="meta_tags_test" content="' . str_replace('\'', '', $faker->word) . '" />')
+        ;
+        $this->app['orm.em']->persist($PageLayout);
+        $this->app['orm.em']->flush($PageLayout);
+        return $PageLayout;
+    }
+
     /**
      * Faker を生成する.
      *
