@@ -49,7 +49,12 @@ class CustomerRepositoryGetQueryBuilderBySearchDataTest extends EccubeTestCase
 
     public function testMultiWithId()
     {
-        $this->expected = $this->Customer->getId();
+        // 検索時, IDの重複を防ぐため事前に5個生成しておく
+        for ($i = 0; $i < 10; $i++) {
+            $this->createCustomer('user-'.$i.'@example.com');
+        }
+        $Customer = $this->createCustomer('customer@example.jp');
+        $this->expected = $Customer->getId();
         $this->searchData = array(
             'multi' => $this->expected
         );
@@ -298,14 +303,19 @@ class CustomerRepositoryGetQueryBuilderBySearchDataTest extends EccubeTestCase
 
     public function testBirthMonth()
     {
-        // TODO 本体未実装
+        $this->Customer->setBirth(new \DateTime('2016-09-29'));
+        $this->Customer1->setBirth(new \DateTime('2010-09-01'));
+        $this->Customer2->setBirth(new \DateTime('2016-01-01'));
+        $this->Customer3->setBirth(null);
+        $this->app['orm.em']->flush();
+
         $this->searchData = array(
-            'birth_month' => 5
+            'birth_month' => 9
         );
 
         $this->scenario();
 
-        $this->expected = 4;
+        $this->expected = 2;
         $this->actual = count($this->Results);
         $this->verify();
     }
