@@ -2,9 +2,9 @@
 /*
  * This file is part of EC-CUBE
  *
- * Copyright(c) 2000-2015 LOCKON CO.,LTD. All Rights Reserved.
+ * Copyright(c) EC-CUBE CO.,LTD. All Rights Reserved.
  *
- * http://www.lockon.co.jp/
+ * http://www.ec-cube.co.jp/
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -150,8 +150,12 @@ class ShoppingControllerWithNonmemberTest extends AbstractShoppingControllerTest
         $this->assertNotNull($this->app['session']->get('eccube.front.shopping.nonmember.customeraddress'));
 
         $this->expected = $formData['name']['name01'];
-        $this->actual = $Nonmember['customer']->getName01();
-        $this->verify();
+        $this->actual = $Nonmember['name01'];
+        $this->verify('name01はセッションに保存されているか');
+
+        $this->expected = $formData['email']['first'];
+        $this->actual = $Nonmember['customer']->getEmail();
+        $this->verify('Email はセッションから unserialize されているか');
 
         $this->assertTrue($client->getResponse()->isRedirect($this->app->url('shopping')));
     }
